@@ -9,7 +9,7 @@ use URI::Encode qw( uri_encode );
 use POSIX qw( strftime );
 use Data::UUID;
 
-our $VERSION = '0.400';
+our $VERSION = '0.401';
 
 my $XMLer = Search::Tools::XML->new;
 
@@ -26,9 +26,13 @@ sub stringify {
     my $self       = shift;
     my $pager      = $self->build_pager();
     my $UUID_maker = Data::UUID->new;
+
+    # must get results->mtime before build_entries
+    # because mtime gets deleted in build_entries.
+    my $resp_mtime = $self->get_mtime();
     my @entries    = $self->_build_entries;
 
-    my $now = strftime $AtomDT, gmtime;
+    my $now = strftime $AtomDT, gmtime($resp_mtime);
     my $query = $self->query;
     $query = "" unless defined $query;
 
